import Form from '@/widgets/form/form.widget';
import classes from './styles.module.scss';
import TV from '@shared/assets/images/tv.png';
import { FormEvent, useCallback, useEffect, useState } from 'react';
import {
  TVCreatePredictType,
  TVGetDataPredictType,
  PredictResponseType,
} from '@/shared/types';
import { apiTV } from '@/shared/api';
import { motion } from 'framer-motion';

const TVPredictPage = () => {
  const [requestSelectorsData, setRequestSelectorsData] = useState<
    TVGetDataPredictType | undefined
  >();

  const [request, setRequest] = useState<TVCreatePredictType>({
    display: '',
    tuners: '',
    features: '',
    os: '',
    power_of_volume: '',
    screen_size: 0,
    color: '',
  });

  const [response, setResponse] = useState<PredictResponseType>({
    predicted_price: undefined,
  });

  const handleGetPredict = async (event: FormEvent) => {
    event.preventDefault();
    if (response.predicted_price) {
      setResponse({
        predicted_price: undefined,
      });
      return;
    }
    const newResponse = await apiTV.predictPrice(request);
    setResponse(newResponse);
  };

  const handleInputChange = useCallback(
    (updatedRequest: TVCreatePredictType) => {
      setRequest(updatedRequest);
    },
    [],
  );

  const updateField = (
    field: keyof TVGetDataPredictType,
    value: string | number,
  ) => {
    handleInputChange({
      ...request,
      [field]: value,
    });
  };

  useEffect(() => {
    const fetchData = async () => {
      const responseSelectorData = await apiTV.getDataForRequest();
      if (!responseSelectorData) {
        return;
      }
      setRequestSelectorsData(responseSelectorData);
    };

    fetchData();
  }, []);

  const iconVariants = {
    hidden: { x: -100, opacity: 0 },
    visible: { x: 0, opacity: 1 },
  };

  const containerVariants = {
    hidden: { x: 100, opacity: 0 },
    visible: { x: 0, opacity: 1 },
  };

  return (
    <div className={classes.tv}>
      <motion.img
        src={TV}
        className={classes.icon}
        initial="hidden"
        animate="visible"
        variants={iconVariants}
        transition={{ duration: 0.5 }}
      />
      <motion.div
        className={classes.container}
        initial="hidden"
        animate="visible"
        variants={containerVariants}
        transition={{ duration: 0.5 }}
      >
        <Form
          selectorsData={requestSelectorsData}
          updateField={updateField}
          handleGetPredict={handleGetPredict}
          response={response}
        />
      </motion.div>
    </div>
  );
};

export default TVPredictPage;
